@@ -34,8 +34,7 @@ fn simple_format(old_text: &str, new_text: &str) -> (Vec<String>, Vec<String>) {
     }
     if (!old_text.is_empty()) && !old_text.ends_with('\n') {
         old_lines.push(format!(
-            "{}{}{}",
-            NO_EOF_NEWLINE_COLOR, NO_EOF_NEWLINE_MARKER, NORMAL
+            "{NO_EOF_NEWLINE_COLOR}{NO_EOF_NEWLINE_MARKER}{NORMAL}"
         ));
     }
 
@@ -45,8 +44,7 @@ fn simple_format(old_text: &str, new_text: &str) -> (Vec<String>, Vec<String>) {
     }
     if (!new_text.is_empty()) && !new_text.ends_with('\n') {
         new_lines.push(format!(
-            "{}{}{}",
-            NO_EOF_NEWLINE_COLOR, NO_EOF_NEWLINE_MARKER, NORMAL
+            "{NO_EOF_NEWLINE_COLOR}{NO_EOF_NEWLINE_MARKER}{NORMAL}"
         ));
     }
 
@@ -107,8 +105,15 @@ fn format_split(old_text: &str, new_text: &str) -> Option<(Vec<String>, Vec<Stri
     let mut new_collector = TokenCollector::create(StyledToken::new("+".to_string(), Style::New));
 
     // Tokenize adds and removes before diffing them
-    let tokenized_old = tokenizer::tokenize(old_text);
-    let tokenized_new = tokenizer::tokenize(new_text);
+    let mut tokenized_old = tokenizer::tokenize(old_text);
+    let mut tokenized_new = tokenizer::tokenize(new_text);
+
+    // Help visualize what actually happens in "No newline at end of file" diffs
+    if old_text.ends_with('\n') && !new_text.ends_with('\n') {
+        tokenized_old.insert(tokenized_old.len() - 1, "⏎");
+    } else if new_text.ends_with('\n') && !old_text.ends_with('\n') {
+        tokenized_new.insert(tokenized_new.len() - 1, "⏎");
+    }
 
     let diff = tokenized_old.diff(&tokenized_new);
     match diff {
@@ -161,8 +166,7 @@ fn to_lines(old: &str, new: &str) -> (Vec<String>, Vec<String>) {
     }
     if (!old.is_empty()) && !old.ends_with('\n') {
         old_lines.push(format!(
-            "{}{}{}",
-            NO_EOF_NEWLINE_COLOR, NO_EOF_NEWLINE_MARKER, NORMAL
+            "{NO_EOF_NEWLINE_COLOR}{NO_EOF_NEWLINE_MARKER}{NORMAL}"
         ));
     }
 
@@ -172,8 +176,7 @@ fn to_lines(old: &str, new: &str) -> (Vec<String>, Vec<String>) {
     }
     if (!new.is_empty()) && !new.ends_with('\n') {
         new_lines.push(format!(
-            "{}{}{}",
-            NO_EOF_NEWLINE_COLOR, NO_EOF_NEWLINE_MARKER, NORMAL
+            "{NO_EOF_NEWLINE_COLOR}{NO_EOF_NEWLINE_MARKER}{NORMAL}"
         ));
     }
 
@@ -235,12 +238,10 @@ mod tests {
             result,
             [
                 format!(
-                    "{}-{}<{}unchanged text between quotes{}>{}",
-                    OLD, INVERSE_VIDEO, NOT_INVERSE_VIDEO, INVERSE_VIDEO, NORMAL
+                    "{OLD}-{INVERSE_VIDEO}<{NOT_INVERSE_VIDEO}unchanged text between quotes{INVERSE_VIDEO}>{NORMAL}"
                 ),
                 format!(
-                    "{}+{}[{}unchanged text between quotes{}]{}",
-                    NEW, INVERSE_VIDEO, NOT_INVERSE_VIDEO, INVERSE_VIDEO, NORMAL
+                    "{NEW}+{INVERSE_VIDEO}[{NOT_INVERSE_VIDEO}unchanged text between quotes{INVERSE_VIDEO}]{NORMAL}"
                 ),
             ]
         )
@@ -249,9 +250,9 @@ mod tests {
     #[test]
     fn test_almost_empty_changes() {
         let result = format("x\n", "");
-        assert_eq!(result, [format!("{}-x{}", OLD, NORMAL),]);
+        assert_eq!(result, [format!("{OLD}-x{NORMAL}"),]);
 
         let result = format("", "x\n");
-        assert_eq!(result, [format!("{}+x{}", NEW, NORMAL),]);
+        assert_eq!(result, [format!("{NEW}+x{NORMAL}"),]);
     }
 }
